@@ -3,7 +3,7 @@ BEGIN {
   $App::EvalServer::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::EvalServer::VERSION = '0.05';
+  $App::EvalServer::VERSION = '0.06';
 }
 
 use strict;
@@ -326,6 +326,9 @@ sub eval_sig_child {
         if ($eval->{return}{error}) {
             $client->put({ error => $eval->{return}{error} });
         }
+        elsif (!exists $eval->{return}{result}) {
+            $client->put({ error => 'Child process died before returning a result.' });
+        }
         else {
             $client->put($eval->{return});
         }
